==> haskell-dbus-hslogger-0.1.0.1-378-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-8zIjLITwQq2Ce5ODiKHH0q
key:                  dbus-hslogger-0.1.0.1-8zIjLITwQq2Ce5ODiKHH0q
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  ea30d3dd71f334e3515615187f7851b6
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-8zIjLITwQq2Ce5ODiKHH0q
depends:
    base-4.15.1.0 dbus-1.2.22-9MJQjLNK44KDWs0JXiHJpX
    hslogger-1.3.1.0-KzlhBMOSSdaFDR3rkwktqA

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus-hslogger-0.1.0.1-439-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-FKZ3Y13gw4e8EEnM2YppGt
key:                  dbus-hslogger-0.1.0.1-FKZ3Y13gw4e8EEnM2YppGt
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  0d441581d99143770b4b4d3057b3fe45
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-FKZ3Y13gw4e8EEnM2YppGt
depends:
    base-4.15.1.0 dbus-1.2.22-4aPnULQzBVW8f2vFMszzZ4
    hslogger-1.3.1.0-8EmNMt8WvrC4dQ5b2HGLzn

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
